#!/bin/sh

#SBATCH -A fnrdewoody
#SBATCH -N 1 -n 20
#SBATCH -t 14-00:00:00
#SBATCH --job-name="GATK pipeline"
#SBATCH --mail-type=ALL
#SBATCH -o GATK.out
#SBATCH -e GATK.err

module purge
module load bioinfo
module load bwa

# required input files:
# ref.fa = reference fasta file
# R1.fastq + R2.fastq = wgs read fastq files

## STEP 1
# index reference and map reads
bwa index -a bwtsw ref.fa

## STEP 2
LINE=$"edwardsii"
FILE=$"edwardsii"
# make a DIR for each species with the reference and the PE reads

# map reads to bam
bwa mem -t 10 -M -R "@RG\tID:group1\tSM:$LINE\tPL:illumina\tLB:lib1\tPU:unit1" \
ref.fa R1.fastq R2.fastq > ${LINE}.sam

## STEP 3
module load samtools
module load picard-tools

# validate sam file
# you need to check that the output file has NO errors
PicardCommandLine ValidateSamFile I=${FILE}.sam MODE=SUMMARY O=${FILE}_samfile.txt
PicardCommandLine SortSam SORT_ORDER=coordinate INPUT=${FILE}.sam OUTPUT=out.bam \
TMP_DIR=`pwd`/tmp VALIDATION_STRINGENCY=LENIENT

# marking PCR duplicated reads without removing them
PicardCommandLine MarkDuplicates INPUT=out.bam OUTPUT=marked.bam M=metrics.txt

# check coverage
PicardCommandLine CollectWgsMetrics I=marked.bam \
O=coverage_marked.txt R=ref.fa

PicardCommandLine BuildBamIndex INPUT=marked.bam

# create reference that reads can be mapped to. Will produce .fai file
samtools faidx ref.fa

PicardCommandLine CreateSequenceDictionary \
reference=ref.fa output=ref.dict

## STEP 4
module load GATK/3.8.1

GenomeAnalysisTK -nt 10 -T RealignerTargetCreator \
-R ref.fa -I marked.bam \
-o forIndelRealigner.intervals

GenomeAnalysisTK -T IndelRealigner \
-R ref.fa -I marked.bam \
-targetIntervals forIndelRealigner.intervals -o realigned_reads.bam

## STEP 5
# you can skip this step if you already indexed your files
# index bam file
cp realigned_reads.bam ${LINE}.bam
PicardCommandLine BuildBamIndex INPUT=${LINE}.bam

# Run HaplotypeCaller
GenomeAnalysisTK -T HaplotypeCaller -R ref.fa -I ${LINE}.bam -nct 5 \
--emitRefConfidence GVCF -stand_call_conf 0 --min_base_quality_score 20 \
--min_mapping_quality_score 20 -o ${LINE}.g.vcf

## STEP 6
mkdir tmp

# you need to set the path to your tmp in the following
# convert g.vcf to vcf
java -Djava.io.tmpdir=./tmp/ \
	-jar $GATK -T GenotypeGVCFs \
   -R ref.fa \
   --variant ${FILE}.g.vcf \
   -o ${FILE}.vcf

## STEP 7
vcfutils.pl qstats ${FILE}.vcf > SNP_stats.txt

#END
